@@ -4,11 +4,11 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/acp.el
-;; Package-Version: 0.8.3
-;; Package-Revision: 9ab9b8f25cd7
+;; Package-Version: 0.9.1
+;; Package-Revision: 771e01e8605c
 ;; Package-Requires: ((emacs "28.1"))
 
-(defconst acp-package-version "0.8.3")
+(defconst acp-package-version "0.9.1")
 
 ;; This package is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -426,11 +426,14 @@ When non-nil SYNC, send notification synchronously."
         result))))
 
 (cl-defun acp-make-initialize-request (&key protocol-version
+                                            client-info
                                             read-text-file-capability
                                             write-text-file-capability)
   "Instantiate an \"initialize\" request.
 
 PROTOCOL-VERSION is the version of the ACP protocol to use.
+CLIENT-INFO is an optional alist with client information containing
+keys like `name', `title', and `version'.
 READ-TEXT-FILE-CAPABILITY is a boolean indicating if the client
 can read text files.
 WRITE-TEXT-FILE-CAPABILITY is a boolean indicating if the client
@@ -441,7 +444,9 @@ and https://agentclientprotocol.com/protocol/schema#initializeresponse."
   (unless protocol-version
     (error ":protocol-version is required"))
   `((:method . "initialize")
-    (:params . ((protocolVersion . ,protocol-version)
+    (:params . (,@(when client-info
+                    `((clientInfo . ,client-info)))
+                (protocolVersion . ,protocol-version)
                 (clientCapabilities . ((fs . ((readTextFile . ,(if read-text-file-capability
                                                                    t
                                                                  :false))
